aaa = "a印巴冲突2025workbook_20250510150753972170"

bbb = r'https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/a%E5%8D%B0%E5%B7%B4%E5%86%B2%E7%AA%812025workbook_20250510150753972170.xlsx'

import f_excel.over.open_and_process_excel as op

ccc = op.open_and_process_excel(bbb)