aaa = "飞机导弹列表workbook_20250510145743707399"

bbb = r'https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/%E9%A3%9E%E6%9C%BA%E5%AF%BC%E5%BC%B9%E5%88%97%E8%A1%A8workbook_20250510145743707399.xlsx'

import f_excel.over.open_and_process_excel as op

ccc = op.open_and_process_excel(bbb)